# wds-client
This page lists current APIs.

As of v0.2, all APIs are subject to change without notice.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v0.2
- Package version: 0.2.66
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import wds_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import wds_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import wds_client
from wds_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://..
# See configuration.py for a list of all supported configuration parameters.
configuration = wds_client.Configuration(
    host = "http://.."
)



# Enter a context with an instance of the API client
with wds_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = wds_client.GeneralWDSInformationApi(api_client)
    
    try:
        # Gets health status for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#health for details)
        api_response = api_instance.status_get()
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling GeneralWDSInformationApi->status_get: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://..*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*GeneralWDSInformationApi* | [**status_get**](docs/GeneralWDSInformationApi.md#status_get) | **GET** /status | Gets health status for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#health for details)
*GeneralWDSInformationApi* | [**version_get**](docs/GeneralWDSInformationApi.md#version_get) | **GET** /version | Gets related git and build version info for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#info for details)
*InstancesApi* | [**create_wds_instance**](docs/InstancesApi.md#create_wds_instance) | **POST** /instances/{v}/{instanceid} | Create an instance
*InstancesApi* | [**delete_wds_instance**](docs/InstancesApi.md#delete_wds_instance) | **DELETE** /instances/{v}/{instanceid} | Delete an instance
*InstancesApi* | [**list_wds_instances**](docs/InstancesApi.md#list_wds_instances) | **GET** /instances/{v} | List instances
*RecordsApi* | [**batch_write_records**](docs/RecordsApi.md#batch_write_records) | **POST** /{instanceid}/batch/{v}/{type} | Batch write records
*RecordsApi* | [**create_or_replace_record**](docs/RecordsApi.md#create_or_replace_record) | **PUT** /{instanceid}/records/{v}/{type}/{id} | Create or replace record
*RecordsApi* | [**delete_record**](docs/RecordsApi.md#delete_record) | **DELETE** /{instanceid}/records/{v}/{type}/{id} | Delete record
*RecordsApi* | [**get_record**](docs/RecordsApi.md#get_record) | **GET** /{instanceid}/records/{v}/{type}/{id} | Get record
*RecordsApi* | [**get_records_as_tsv**](docs/RecordsApi.md#get_records_as_tsv) | **GET** /{instanceid}/tsv/{v}/{type} | Retrieve all records in record type as tsv.
*RecordsApi* | [**query_records**](docs/RecordsApi.md#query_records) | **POST** /{instanceid}/search/{v}/{type} | Query records
*RecordsApi* | [**update_record**](docs/RecordsApi.md#update_record) | **PATCH** /{instanceid}/records/{v}/{type}/{id} | Update record
*RecordsApi* | [**upload_tsv**](docs/RecordsApi.md#upload_tsv) | **POST** /{instanceid}/tsv/{v}/{type} | Import records to a record type from a tsv file
*SchemaApi* | [**delete_record_type**](docs/SchemaApi.md#delete_record_type) | **DELETE** /{instanceid}/types/{v}/{type} | Delete record type
*SchemaApi* | [**describe_all_record_types**](docs/SchemaApi.md#describe_all_record_types) | **GET** /{instanceid}/types/{v} | Describe all record types
*SchemaApi* | [**describe_record_type**](docs/SchemaApi.md#describe_record_type) | **GET** /{instanceid}/types/{v}/{type} | Describe record type


## Documentation For Models

 - [AttributeSchema](docs/AttributeSchema.md)
 - [BatchOperation](docs/BatchOperation.md)
 - [BatchRecordRequest](docs/BatchRecordRequest.md)
 - [BatchResponse](docs/BatchResponse.md)
 - [Build](docs/Build.md)
 - [Commit](docs/Commit.md)
 - [Component](docs/Component.md)
 - [Components](docs/Components.md)
 - [DbComponent](docs/DbComponent.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [Git](docs/Git.md)
 - [InlineObject](docs/InlineObject.md)
 - [RecordAttributeDefinition](docs/RecordAttributeDefinition.md)
 - [RecordQueryResponse](docs/RecordQueryResponse.md)
 - [RecordRequest](docs/RecordRequest.md)
 - [RecordResponse](docs/RecordResponse.md)
 - [RecordTypeSchema](docs/RecordTypeSchema.md)
 - [RequestBodySearch](docs/RequestBodySearch.md)
 - [SearchOperator](docs/SearchOperator.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SearchSortDirection](docs/SearchSortDirection.md)
 - [StackTraceElement](docs/StackTraceElement.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [TsvUploadResponse](docs/TsvUploadResponse.md)
 - [VersionResponse](docs/VersionResponse.md)


## Documentation For Authorization


## bearerAuth

- **Type**: Bearer authentication


## Author




